@@ -22,20 +22,44 @@
 
 #include "../localfilesabstractmodel.h"
 
-#include "localvideothumbnailprovider.h"
+#include "../localthumbnailprovider.h"
 
+/**
+  * @class LocalVideosModel @author Shantanu Tushar 
+  * @brief Model for Local Videos
+  *
+  * @description  This class is a model for viewing the videos in the local folders
+  * 
+  * This class inherits from LocalFilesAbstractModel 
+  */
 class LocalVideosModel : public LocalFilesAbstractModel
 {
     Q_OBJECT
 public:
+  
+  /**
+     * Constructor
+     * @brief Used for initialization purposes.
+     * 
+     * @description declarative engine is set to enable the thumbnail view and slot for processing the thumbnail connected
+     * 
+     * @param parent is a QObject pointer
+     */
     explicit LocalVideosModel (QObject* parent);
+    
+     /**
+     * Returns the data stored under the given role for the item referred to by the index.
+     * Also thumbnail loading for the folders is here
+     * @param index is of QModelIndex Type
+     * @param role is set to Qt:: DisplayRole which means the key data is to be rendered in the form of text
+     */
     virtual QVariant data (const QModelIndex& index, int role = Qt::DisplayRole) const;
 
 private slots:
     void processThumbnail (const QString& url);
 
 private:
-    VideoThumbnailProvider *m_thumbProvider;
+    ThumbnailProvider *m_thumbProvider;
     mutable QHash<QString, QPersistentModelIndex> m_pendingThumbs;        //aw mutable, any other way to let data() change this?
 };
 
